%
%\BeginDoc
%
%\Name: test_new_vectors 
%
%\Description: 
%    Function appends the set of column vectors
%    N with members in the set Nnew that are minimal(*) to one
%    another and minimal(*) to other vectors in N.
%    (*) 'minimal' in the sign-vector sense.
%
%\Arguments
%   N, Nnew     Nnew is tested with respect to N/Nnew. 
%   option=1    Nnew is tested with respect to N.
%   option=2    Nnew is tested with respect to itself.
%
%\Program outputs:
%   Nadd        Filtered column vectors of Nnew were appended into N.        
%              
%\EndDoc
%
%-------------------------------------------------------------------------    
%        
    function Nadd = test_new_vectors(N,Nnew,option)
%    
%  %------------------------------------%
%  | Change to binary vector.           |
%  %------------------------------------%
%       
    Nadd = []; 
    [m,n] = size(N);
    nnew = size(Nnew,2);  
   
    if n == 0 || nnew == 0
      return
    end

    Ns = (N~=0);    
    Nsnew = abs(sign(Nnew));      
%    
%  %-------------------------------------------------%
%  | Each cycle should has minimum signed supports.  |
%  %-------------------------------------------------%
%     
    for j = 1:nnew  
      if option == 1       %   if N =/= Nnew
        t = Ns'*Nsnew(:,j) - sum(Ns,1)';                             
      else                 %   if N = Nnew
        t = Nsnew(:,j+1:nnew)'*Nsnew(:,j) - sum(Nsnew(:,j+1:nnew),1)';                             
      end
      
      if sum(t~=0) == length(t) 
        Nadd = [Nadd Nnew(:,j)];
      end 
    end 

%    
%  %---------------------------------------%
%  | End of test_new_vectors function      |
%  %---------------------------------------%
% 